# Task: Sort Lines Alphabetically

You are given a text file at `workspace/names.txt` containing a list of names, one per line. Sort the names alphabetically.

## Requirements

1. Read `workspace/names.txt`.
2. Sort all lines in case-sensitive alphabetical order (standard lexicographic sort).
3. Write the sorted result to `workspace/sorted.txt`, one name per line.

## Output

Save the sorted names to `workspace/sorted.txt`.
